summer — summer 0.7.4 documentation

# summer

Summer is light weight Python 3 application framework to support generic application development. It provides support for business object management, ORM (mapping, declarative transactions), LDAP and localization. Inspired by famous Java Spring application framework.

Please use SourceForge project page to download the source code & report bugs.

Quick installation:

    pip install summer

Contents:

- README
- Basic Concepts
- Examples
- summer API doc

# Introduction

Please see README and Basic Concepts for introduction. There are some real world Examples, which require source code reading. The rest of this doc is sphinx generated API reference.

# Indices and tables

- Index

- Module Index

- Search Page